@@ -291,6 +291,7 @@ def write_table(
     write_options: dict = None,
     sort_fields: list = None,
     upsert_fields: list = None,
+    write_stream: bool = True
 ):
     if partition_columns is None:
         partition_columns = list()
@@ -302,14 +303,25 @@ def write_table(
         spark = get_spark_session("upsert_data")
 
     if insert_mode != "upsert":
-        stream = (
-            df.writeStream.trigger(once=True)
-            .format("delta")
-            .option("checkpointLocation", checkpoint_location)
-            .option("header", "true")
-            .option("mergeSchema", "true")
-            .options(**write_options)
-        )
+        if write_stream:
+            stream = (
+                df.writeStream.trigger(once=True)
+                .format("delta")
+                .option("checkpointLocation", checkpoint_location)
+                .option("header", "true")
+                .option("mergeSchema", "true")
+                .options(**write_options)
+            )
+        else:
+            stream = (
+                df.write
+                .format("delta")
+                .option("checkpointLocation", checkpoint_location)
+                .option("header", "true")
+                .option("mergeSchema", "true")
+                .options(**write_options)
+            )
+            return stream
 
     table_exists = check_table_exists(
         spark=spark, db_name=db_name, table_name=table_name
@@ -321,7 +333,7 @@ def write_table(
     if sort_fields and upsert_fields and insert_mode=="upsert":
 
         stream = (
-            df.write.trigger(once=True)
+            df.write
             .format("delta")
             .option("checkpointLocation", checkpoint_location)
             .option("header", "true")
@@ -607,6 +619,7 @@ def landing_to_bronze(
         partition_columns=partition_columns,
         write_options=write_options,
         upsert_fields=upsert_fields,
+        write_stream=True if not input_df else False
     )
 
     db_table = f"{db_name}.{dataset_name}"
@@ -730,6 +743,7 @@ def bronze_to_silver(
         write_options=write_options,
         sort_fields=sort_fields,
         upsert_fields=upsert_fields,
+        write_stream=True if not input_df else False
     )
 
     output_db_table = f"{output_db_name}.{dataset_name}"
@@ -900,6 +914,7 @@ def silver_to_gold(
         write_options=write_options,
         sort_fields=sort_fields,
         upsert_fields=upsert_fields,
+        write_stream=True if not input_df else False
     )
 
     output_db_table = f"{output_db_name}.{dataset_name}"
@@ -1058,6 +1073,7 @@ def gold_to_diamond(
         write_options=write_options,
         sort_fields=sort_fields,
         upsert_fields=upsert_fields,
+        write_stream=True if not input_df else False
     )
 
     output_db_table = f"{output_db_name}.{dataset_name}"
